@@ -10,15 +10,15 @@ from pathlib import Path
 
 # sys.path.append("../EVAtool")
 
-from utils.fastq import Fastq
-from utils.config import Config
-from utils.logger import Logger
-from utils.sam import SAM
-from utils.bam import Bam
-from utils.tag import Tag
-from utils.stat import Stat
-from utils.plot import Plot
-from utils.report import Report
+from evatool.utils.fastq import Fastq
+from evatool.utils.config import Config
+from evatool.utils.logger import Logger
+from evatool.utils.sam import SAM
+from evatool.utils.bam import Bam
+from evatool.utils.tag import Tag
+from evatool.utils.stat import Stat
+from evatool.utils.plot import Plot
+from evatool.utils.report import Report
 
 import argparse
 import datetime
